@@ -203,8 +203,14 @@ def parse_args(args: Any) -> Namespace:
     return Namespace(**{k: None if not v else v for k, v in args.__dict__.items()})
 
 
-def get_arguments(*, pop_class_attributes: bool = True) -> Dict[str, Any]:
+def get_arguments(
+    *,
+    num_back: int = 0,
+    pop_class_attributes: bool = True,
+) -> Dict[str, Any]:
     frame = inspect.currentframe().f_back  # type: ignore
+    for _ in range(num_back):
+        frame = frame.f_back
     if frame is None:
         raise ValueError("`get_arguments` should be called inside a frame")
     arguments = inspect.getargvalues(frame)[-1]
@@ -267,6 +273,25 @@ def hash_code(code: str) -> str:
     return hashlib.md5(code).hexdigest()
 
 
+def hash_dict(d: Dict[str, Any]) -> str:
+    """Return a consistent hash code for an arbitrary dict."""
+
+    def _hash(_d: Dict[str, Any]) -> str:
+        sorted_keys = sorted(_d)
+        hashes = []
+        for k in sorted_keys:
+            v = _d[k]
+            if isinstance(v, dict):
+                hashes.append(_hash(v))
+            elif isinstance(v, set):
+                hashes.append(hash_code(str(sorted(v))))
+            else:
+                hashes.append(hash_code(str(v)))
+        return hash_code("".join(hashes))
+
+    return _hash(d)
+
+
 def random_hash() -> str:
     return hash_code(str(random.random()))
 
